src/hg/hgTracks/hgTracks.h 1.210

1.210 2010/05/11 01:43:27 kent
Refactoring to split the trackDb.tableName field into separate track and table fields. Similarly track.mapName field goes to the same track and table fields.
Index: src/hg/hgTracks/hgTracks.h
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/hgTracks/hgTracks.h,v
retrieving revision 1.209
retrieving revision 1.210
diff -b -B -U 4 -r1.209 -r1.210
--- src/hg/hgTracks/hgTracks.h	7 May 2010 20:37:31 -0000	1.209
+++ src/hg/hgTracks/hgTracks.h	11 May 2010 01:43:27 -0000	1.210
@@ -57,9 +57,10 @@
 /* Structure that displays of tracks. The central data structure
  * of the graphical genome browser. */
     {
     struct track *next;   /* Next on list. */
-    char *mapName;             /* Database track name. Name on image map etc. */
+    char *track;             /* Track symbolic name. Name on image map etc. Same as tdb->track. */
+    char *table;             /* Table symbolic name. Name of database table. Same as tdb->table.*/
     enum trackVisibility visibility; /* How much of this want to see. */
     enum trackVisibility limitedVis; /* How much of this actually see. */
     boolean limitedVisSet;	     /* Is limited visibility set? */